@@ -1,7 +1,7 @@
 #
 # Run this TCL script to generate HTML for the download.html file.
 #
-set rcsid {$Id: download.tcl,v 1.26 2007/04/09 13:18:47 drh Exp $}
+set rcsid {$Id: download.tcl,v 1.27 2007/05/08 18:30:36 drh Exp $}
 source common.tcl
 header {SQLite Download Page}
 
@@ -136,12 +136,20 @@ Product {sqlite-V3.tar.gz} {
 }
 
 Product {sqlite-source-V3.zip} {
-  This ZIP archive contains pure C code for the SQLite library.
+  This ZIP archive contains preprocessed C code for the SQLite library as
+  individual source files.
   Unlike the tarballs below, all of the preprocessing and automatic
   code generation has already been done on these C code files, so they
   can be converted to object code directly with any ordinary C compiler.
 }
 
+Product {sqlite-amalgamation-V3.zip} {
+  This ZIP archive contains all preprocessed C code combined into a
+  single source file (the
+  <a href="http://www.sqlite.org/cvstrac/wiki?p=TheAmalgamation">
+  amalgamation</a>).
+}
+
 Product {sqlite-V3-tea.tar.gz} {
   A tarball of proprocessed source code together with a
   <a href="http://www.tcl.tk/doc/tea/">Tcl Extension Architecture (TEA)</a>
